# -*- coding: utf-8 -*-

# Copyright (c) 2003 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Package implementing the source code documentation tools.
"""

supportedExtensionsDictForApis = {
    "Python2": [".py2", ".pyw2", ".ptl"],
    "Python3": [".py", ".pyw", ".py3", ".pyw3"],
    "Ruby": [".rb"]
}
